@@ -26,26 +26,28 @@ module Data.UUID.Named
     ,namespaceX500
     ) where
 
-import Data.UUID.Internal
+import Data.UUID.Types.Internal
 
 import Control.Applicative ((<*>),(<$>))
 import Data.Binary.Get (runGet, getWord32be)
 import Data.Maybe
 import Data.Word (Word8)
 
+import qualified Data.ByteArray as BA
 import qualified Data.ByteString as B
 import qualified Data.ByteString.Lazy as BL
 
 -- |Generate a 'UUID' within the specified namespace out of the given
 -- object.
-generateNamed :: (B.ByteString -> B.ByteString) -- ^Hash
+generateNamed :: BA.ByteArrayAccess bs
+              => (B.ByteString -> bs) -- ^Hash
               -> Word8   -- ^Version
               ->  UUID   -- ^Namespace
               -> [Word8] -- ^Object
               -> UUID
 generateNamed hash version namespace object =
     let chunk = B.pack $ toList namespace ++ object
-        bytes = BL.fromChunks . (:[]) $ hash chunk
+        bytes = BL.fromStrict . BA.convert $ hash chunk
         w = getWord32be
         unpackBytes = runGet $
          buildFromWords version <$> w <*> w <*> w <*> w
