@@ -33,9 +33,9 @@ module Data.UUID.V3
 
 import Data.Word
 
-import Data.UUID.Internal
+import Data.UUID.Types.Internal
 import qualified Data.UUID.Named as Shared
-import qualified Crypto.Hash.MD5 as MD5
+import qualified Crypto.Hash as H
 
 
 -- |Generate a 'UUID' within the specified namespace out of the given
@@ -46,5 +46,4 @@ import qualified Crypto.Hash.MD5 as MD5
 generateNamed :: UUID    -- ^Namespace
               -> [Word8] -- ^Object
               -> UUID
-generateNamed = Shared.generateNamed MD5.hash 3
-
+generateNamed = Shared.generateNamed (H.hashWith H.MD5) 3
